#line 2 "lex.yy.c"

#line 4 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 58
#define YY_END_OF_BUFFER 59
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[199] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   19,   19,    0,    0,   29,   29,   33,   33,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    5,    5,    7,    7,    0,    0,   57,   57,
       59,   58,    1,    9,    2,   58,    3,   10,   10,   11,
       11,   12,   12,   13,   13,   14,   14,   23,    1,    9,
       21,   23,   19,   22,   20,   18,    3,   25,   24,   30,
        1,    9,   30,   29,   30,   29,   28,   27,   26,   26,
        3,   35,   33,   33,   34,   36,   32,   31,   31,   37,

       38,   39,   39,   40,   45,    1,    9,   42,   45,   43,
       44,   41,    3,   15,   15,   17,   16,   47,   46,   54,
       54,   53,   52,   49,   48,   50,   50,   51,    5,    1,
        2,    5,    3,    6,    7,    1,    8,    2,    7,    3,
       57,   56,   55,    1,    4,   10,    4,   11,    4,   12,
        4,   13,    4,   14,    4,   19,   18,   24,   29,   29,
        0,   29,   29,   26,    0,   26,   33,    0,   33,   33,
       31,    0,   31,   37,   39,    4,   41,   15,    4,   16,
       46,   54,    4,   52,   48,   50,    4,    5,    1,    4,
        7,    1,    4,   57,   55,   29,   33,    0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    1,    1,    1,    1,    1,
        1,    1,    5,    1,    6,    7,    8,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,   10,   11,   12,
       13,   14,    1,    1,   15,   15,   15,   15,   16,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
        1,    1,    1,    1,   15,    1,   15,   15,   15,   15,

       16,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   17,    1,   18,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[19] =
    {   0,
        1,    2,    3,    4,    5,    5,    1,    1,    6,    1,
        7,    1,    1,    1,    8,    8,    7,    9
    } ;

static yyconst flex_int16_t yy_base[237] =
    {   0,
        0,   16,   32,   49,   66,   83,  100,  117,  134,  151,
      168,  185,  203,    0,  211,  217,  233,    0,  247,    0,
      255,    0,  270,  287,  305,    0,  322,  339,    0,    0,
      347,  353,  359,  365,  380,  397,  405,  411,  417,  423,
      438,  455,  472,  489,  506,  522,    0,    0,    2,    6,
       88,  842,   80,  842,  842,   73,  842,    0,   72,    0,
       71,    0,   70,    0,   68,    0,   67,  842,   71,  842,
      842,   64,   62,  842,  842,    0,  842,  842,    0,  842,
       63,  842,   55,    5,   55,  533,  842,  842,    0,  545,
      842,  842,    6,  555,  842,  842,  842,    0,  567,    0,

      842,    0,   54,  842,  842,   59,  842,  842,   51,  842,
      842,    0,  842,    0,   50,  842,    0,  842,    0,    0,
       48,  842,    0,  842,    0,    0,   47,  842,    0,   52,
        0,   40,    0,  842,    0,   45,  842,    0,   38,    0,
        0,  842,    0,   43,  842,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   35,    0,    0,    0,    7,
       33,   16,    0,    0,   32,   30,   21,   20,   22,    0,
        0,   19,   18,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   24,    0,
        0,   11,    0,    0,    0,    3,    2,  842,  583,  592,

      601,  610,  619,  628,  637,  646,  655,  664,  673,  682,
      691,  700,  708,  716,  724,  732,  735,  738,  741,  744,
      747,  755,  758,  766,  769,  772,  780,  783,  786,  794,
      802,  810,  819,  828,  833,  835
    } ;

static yyconst flex_int16_t yy_def[237] =
    {   0,
      199,  199,  200,  200,  201,  201,  202,  202,  203,  203,
      204,  204,  198,   13,    2,    2,  198,   17,    2,   19,
        2,   21,  205,  205,  198,   25,  206,  206,    2,    2,
        2,    2,    2,    2,  207,  207,    2,    2,    2,    2,
      208,  208,  209,  209,  210,  210,    2,    2,  211,  211,
      198,  198,  198,  198,  198,  198,  198,  212,  212,  213,
      213,  214,  214,  215,  215,  216,  216,  198,  198,  198,
      198,  198,  198,  198,  198,  217,  198,  198,  218,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  219,  198,
      198,  198,  198,  198,  198,  198,  198,  220,  198,  221,

      198,  222,  222,  198,  198,  198,  198,  198,  198,  198,
      198,  223,  198,  224,  224,  198,  225,  198,  226,  227,
      227,  198,  228,  198,  229,  230,  230,  198,  231,  231,
      231,  231,  231,  198,  232,  232,  198,  232,  232,  232,
      233,  198,  234,  198,  198,  212,  212,  213,  213,  214,
      214,  215,  215,  216,  216,  198,  217,  218,   86,  198,
      235,  198,   86,  219,  198,  219,  198,  236,  198,   94,
      220,  198,  220,  221,  222,  222,  223,  224,  224,  225,
      226,  227,  227,  228,  229,  230,  230,  231,  231,  231,
      232,  232,  232,  233,  234,  198,  198,    0,  198,  198,

      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198
    } ;

static yyconst flex_int16_t yy_nxt[861] =
    {   0,
      198,   53,   54,   55,  142,  143,  198,   56,  142,  143,
      197,  196,  192,  160,  167,  160,   57,   53,   54,   55,
      161,  168,  161,   56,  160,  189,  173,  197,  197,  167,
      167,  161,   57,   53,   54,   55,  168,  168,  166,   59,
      196,  196,   52,  156,  144,  193,  192,  190,   57,   52,
       53,   54,   55,  189,  187,  183,   59,  179,  145,   52,
      144,  176,  145,  159,  144,   57,   52,   53,   54,   55,
      156,  145,  144,   61,  155,  153,   52,  151,  149,  147,
      145,  144,   57,   52,   53,   54,   55,  198,  198,  198,
       61,  198,  198,   52,  198,  198,  198,  198,  198,   57,

       52,   53,   54,   55,  198,  198,  198,   63,  198,  198,
       52,  198,  198,  198,  198,  198,   57,   52,   53,   54,
       55,  198,  198,  198,   63,  198,  198,   52,  198,  198,
      198,  198,  198,   57,   52,   53,   54,   55,  198,  198,
      198,   65,  198,  198,   52,  198,  198,  198,  198,  198,
       57,   52,   53,   54,   55,  198,  198,  198,   65,  198,
      198,   52,  198,  198,  198,  198,  198,   57,   52,   53,
       54,   55,  198,  198,  198,   67,  198,  198,   52,  198,
      198,  198,  198,  198,   57,   52,   53,   54,   55,  198,
      198,  198,   67,  198,  198,   52,  198,  198,  198,  198,

      198,   57,   52,   68,   69,   70,   55,   71,   68,   68,
       72,   73,   68,   74,   68,   75,   68,   76,   76,   77,
       68,   78,  198,  198,  198,   79,   79,   78,  198,  198,
      198,   79,   79,   80,   81,   82,   55,   83,   83,   84,
       85,   86,   80,   87,   80,   88,   80,   89,   90,   91,
       80,   92,   92,   93,  198,   94,   95,  198,   96,   97,
      198,   98,   99,  100,  198,  198,  198,  198,  101,  100,
      100,   53,   54,   55,  198,  198,  198,  103,  198,  198,
      104,  198,  198,  198,  198,  198,   57,   52,   53,   54,
       55,  198,  198,  198,  103,  198,  198,  104,  198,  198,

      198,  198,  198,   57,   52,  105,  106,  107,   55,  108,
      105,  105,  109,  105,  110,  111,  105,  105,  105,  112,
      112,  113,  105,   53,   54,   55,  198,  198,  198,  115,
      198,  198,   52,  198,  198,  198,  198,  198,   57,   52,
       53,   54,   55,  198,  198,  198,  115,  198,  198,   52,
      198,  198,  198,  198,  198,   57,   52,  116,  198,  198,
      198,  117,  117,  116,  198,  198,  198,  117,  117,  118,
      198,  198,  198,  119,  119,  118,  198,  198,  198,  119,
      119,   53,   54,   55,  198,  198,  198,  121,  198,  198,
       52,  198,  198,  198,  198,  198,   57,   52,   53,   54,

       55,  198,  198,  198,  121,  198,  198,   52,  198,  198,
      198,  198,  198,   57,   52,  122,  198,  198,  198,  123,
      123,  122,  198,  198,  198,  123,  123,  124,  198,  198,
      198,  125,  125,  124,  198,  198,  198,  125,  125,   53,
       54,   55,  198,  198,  198,  127,  198,  198,  128,  198,
      198,  198,  198,  198,   57,   52,   53,   54,   55,  198,
      198,  198,  127,  198,  198,  128,  198,  198,  198,  198,
      198,   57,   52,  130,   54,  131,  198,  198,  198,  132,
      198,  198,  198,  198,  198,  198,  198,  198,  133,  134,
      130,   54,  131,  198,  198,  198,  132,  198,  198,  198,

      198,  198,  198,  198,  198,  133,  134,  136,  137,  138,
      198,  198,  198,  139,  198,  198,  198,  198,  198,  198,
      198,  198,  140,  136,  137,  138,  198,  198,  198,  139,
      198,  198,  198,  198,  198,  198,  198,  198,  140,  162,
      198,  163,  198,  198,  198,  198,  198,  198,  161,  165,
      165,  198,  198,  166,  198,  198,  198,  198,  198,  164,
      164,  169,  198,  170,  198,  198,  198,  198,  198,  198,
      168,  172,  172,  198,  198,  173,  198,  198,  198,  198,
      198,  171,  171,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   58,   58,   58,   58,   58,   58,   58,   58,

       58,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   66,   66,
       66,   66,   66,   66,   66,   66,   66,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  114,  114,  114,  114,
      114,  114,  114,  114,  114,  120,  120,  120,  120,  120,
      120,  120,  120,  120,  126,  126,  126,  126,  126,  126,
      126,  126,  126,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  141,  141,  141,  141,  141,  141,  141,  141,  141,

      146,  198,  198,  198,  146,  146,  198,  146,  148,  198,
      198,  198,  148,  148,  198,  148,  150,  198,  198,  198,
      150,  150,  198,  150,  152,  198,  198,  198,  152,  152,
      198,  152,  154,  198,  198,  198,  154,  154,  198,  154,
      157,  198,  157,  158,  198,  158,  164,  198,  164,  171,
      198,  171,  174,  198,  174,  175,  198,  198,  198,  175,
      175,  198,  175,  177,  198,  177,  178,  198,  198,  198,
      178,  178,  198,  178,  180,  198,  180,  181,  198,  181,
      182,  198,  198,  198,  182,  182,  198,  182,  184,  198,
      184,  185,  198,  185,  186,  198,  198,  198,  186,  186,

      198,  186,  188,  188,  198,  188,  188,  188,  188,  188,
      191,  191,  198,  191,  191,  191,  191,  191,  191,  194,
      194,  198,  198,  194,  194,  194,  194,  194,  195,  198,
      198,  195,  195,  195,  195,  195,  195,  165,  165,  172,
      172,   51,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198
    } ;

static yyconst flex_int16_t yy_chk[861] =
    {   0,
        0,    1,    1,    1,   49,   49,    0,    1,   50,   50,
      197,  196,  192,   84,   93,  160,    1,    2,    2,    2,
       84,   93,  160,    2,  162,  189,  173,  172,  168,  167,
      169,  162,    2,    3,    3,    3,  167,  169,  166,    3,
      165,  161,    3,  156,  144,  139,  136,  132,    3,    3,
        4,    4,    4,  130,  127,  121,    4,  115,  109,    4,
      106,  103,   85,   83,   81,    4,    4,    5,    5,    5,
       73,   72,   69,    5,   67,   65,    5,   63,   61,   59,
       56,   53,    5,    5,    6,    6,    6,   51,    0,    0,
        6,    0,    0,    6,    0,    0,    0,    0,    0,    6,

        6,    7,    7,    7,    0,    0,    0,    7,    0,    0,
        7,    0,    0,    0,    0,    0,    7,    7,    8,    8,
        8,    0,    0,    0,    8,    0,    0,    8,    0,    0,
        0,    0,    0,    8,    8,    9,    9,    9,    0,    0,
        0,    9,    0,    0,    9,    0,    0,    0,    0,    0,
        9,    9,   10,   10,   10,    0,    0,    0,   10,    0,
        0,   10,    0,    0,    0,    0,    0,   10,   10,   11,
       11,   11,    0,    0,    0,   11,    0,    0,   11,    0,
        0,    0,    0,    0,   11,   11,   12,   12,   12,    0,
        0,    0,   12,    0,    0,   12,    0,    0,    0,    0,

        0,   12,   12,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   15,    0,    0,    0,   15,   15,   16,    0,    0,
        0,   16,   16,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   19,   19,   19,    0,   19,   19,    0,   19,   19,
        0,   19,   19,   21,    0,    0,    0,    0,   21,   21,
       21,   23,   23,   23,    0,    0,    0,   23,    0,    0,
       23,    0,    0,    0,    0,    0,   23,   23,   24,   24,
       24,    0,    0,    0,   24,    0,    0,   24,    0,    0,

        0,    0,    0,   24,   24,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   27,   27,   27,    0,    0,    0,   27,
        0,    0,   27,    0,    0,    0,    0,    0,   27,   27,
       28,   28,   28,    0,    0,    0,   28,    0,    0,   28,
        0,    0,    0,    0,    0,   28,   28,   31,    0,    0,
        0,   31,   31,   32,    0,    0,    0,   32,   32,   33,
        0,    0,    0,   33,   33,   34,    0,    0,    0,   34,
       34,   35,   35,   35,    0,    0,    0,   35,    0,    0,
       35,    0,    0,    0,    0,    0,   35,   35,   36,   36,

       36,    0,    0,    0,   36,    0,    0,   36,    0,    0,
        0,    0,    0,   36,   36,   37,    0,    0,    0,   37,
       37,   38,    0,    0,    0,   38,   38,   39,    0,    0,
        0,   39,   39,   40,    0,    0,    0,   40,   40,   41,
       41,   41,    0,    0,    0,   41,    0,    0,   41,    0,
        0,    0,    0,    0,   41,   41,   42,   42,   42,    0,
        0,    0,   42,    0,    0,   42,    0,    0,    0,    0,
        0,   42,   42,   43,   43,   43,    0,    0,    0,   43,
        0,    0,    0,    0,    0,    0,    0,    0,   43,   43,
       44,   44,   44,    0,    0,    0,   44,    0,    0,    0,

        0,    0,    0,    0,    0,   44,   44,   45,   45,   45,
        0,    0,    0,   45,    0,    0,    0,    0,    0,    0,
        0,    0,   45,   46,   46,   46,    0,    0,    0,   46,
        0,    0,    0,    0,    0,    0,    0,    0,   46,   86,
        0,   86,    0,    0,    0,    0,    0,    0,   86,   90,
       90,    0,    0,   90,    0,    0,    0,    0,    0,   90,
       90,   94,    0,   94,    0,    0,    0,    0,    0,    0,
       94,   99,   99,    0,    0,   99,    0,    0,    0,    0,
        0,   99,   99,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  200,  200,  200,  200,  200,  200,  200,  200,

      200,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      202,  202,  202,  202,  202,  202,  202,  202,  202,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  204,  204,
      204,  204,  204,  204,  204,  204,  204,  205,  205,  205,
      205,  205,  205,  205,  205,  205,  206,  206,  206,  206,
      206,  206,  206,  206,  206,  207,  207,  207,  207,  207,
      207,  207,  207,  207,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  209,  209,  209,  209,  209,  209,  209,
      209,  209,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  211,  211,  211,  211,  211,  211,  211,  211,  211,

      212,    0,    0,    0,  212,  212,    0,  212,  213,    0,
        0,    0,  213,  213,    0,  213,  214,    0,    0,    0,
      214,  214,    0,  214,  215,    0,    0,    0,  215,  215,
        0,  215,  216,    0,    0,    0,  216,  216,    0,  216,
      217,    0,  217,  218,    0,  218,  219,    0,  219,  220,
        0,  220,  221,    0,  221,  222,    0,    0,    0,  222,
      222,    0,  222,  223,    0,  223,  224,    0,    0,    0,
      224,  224,    0,  224,  225,    0,  225,  226,    0,  226,
      227,    0,    0,    0,  227,  227,    0,  227,  228,    0,
      228,  229,    0,  229,  230,    0,    0,    0,  230,  230,

        0,  230,  231,  231,    0,  231,  231,  231,  231,  231,
      232,  232,    0,  232,  232,  232,  232,  232,  232,  233,
      233,    0,    0,  233,  233,  233,  233,  233,  234,    0,
        0,  234,  234,  234,  234,  234,  234,  235,  235,  236,
      236,  198,  198,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  198,  198,  198,  198,  198,  198,  198
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scan.l"
/******************************************************************************

  KPP - The Kinetic PreProcessor
        Builds simulation code for chemical kinetic systems

  Copyright (C) 1995-1996 Valeriu Damian and Adrian Sandu
  Copyright (C) 1997-2005 Adrian Sandu

  KPP is free software; you can redistribute it and/or modify it under the
  terms of the GNU General Public License as published by the Free Software
  Foundation (http://www.gnu.org/copyleft/gpl.html); either version 2 of the
  License, or (at your option) any later version.

  KPP is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, consult http://www.gnu.org/copyleft/gpl.html or
  write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307,  USA.

  Adrian Sandu
  Computer Science Department
  Virginia Polytechnic Institute and State University
  Blacksburg, VA 24060
  E-mail: sandu@cs.vt.edu

******************************************************************************/
/******************************************************************************
  bug fixes for upgrading from yacc to bison implemented by Rolf Sander,
  following suggestions from Jason Lander <jason@env.leeds.ac.uk>
******************************************************************************/
 
 
 



#line 45 "scan.l"
  #include <string.h> /* strcpy, strlen */
  #include "gdata.h" 
  #include "scan.h" 
  #include "y.tab.h"

  void Include ( char * filename );
  int EndInclude();

  int crt_line_no = 1;
  char *crt_filename;

  #define MAX_INCLUDE 10
  
  YY_BUFFER_STATE yy_buffers[ MAX_INCLUDE ];
  int yy_line_no[ MAX_INCLUDE ];
  char *yy_filename[ MAX_INCLUDE ];
  int yy_buf_level = 0;
  
  char crtToken[300];
  char nextToken[300];
  int crtTokType;
  int nextTokType;
  int crtLine;
  char crtFile[300];
  char crt_rate[300];

  int oldnErr = 0;

  int idx;
  int oldstate;
  extern int yyerrflag;

  typedef struct {
                   char *name;
                   int next;
                   int cmd; 
                 } KEYWORD;

  KEYWORD keywords[];

  int CheckKeyword( char *cmd );

#define RETURN( x ) \
        if(1) { \
          if ( yyerrflag == 0) { \
            strcpy( crtToken, nextToken ); \
            crtTokType = nextTokType; \
            crtLine = crt_line_no; \
            strcpy( crtFile, crt_filename ); \
          } \
          strcpy( nextToken, yytext); \
          nextTokType = x; \
          return (x); \
        }
#line 803 "lex.yy.c"

#define INITIAL 0
#define CMD_STATE 1
#define INC_STATE 2
#define MOD_STATE 3
#define INT_STATE 4
#define PRM_STATE 5
#define DSP_STATE 6
#define SSP_STATE 7
#define INI_STATE 8
#define EQN_STATE 9
#define EQNTAG_STATE 10
#define RATE_STATE 11
#define LMP_STATE 12
#define CR_IGNORE 13
#define SC_IGNORE 14
#define ATM_STATE 15
#define LKT_STATE 16
#define INL_STATE 17
#define MNI_STATE 18
#define TPT_STATE 19
#define USE_STATE 20
#define COMMENT 21
#define COMMENT2 22
#define EQN_ID 23
#define INL_CODE 24

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 120 "scan.l"

#line 1011 "lex.yy.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 199 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 842 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 121 "scan.l"
{
                        }  
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 123 "scan.l"
{ BEGIN CMD_STATE; 
                        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 125 "scan.l"
{ oldstate = (yy_start - 1) / 2;
                          BEGIN COMMENT;
			}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 128 "scan.l"
{ oldstate = (yy_start - 1) / 2;
                          BEGIN COMMENT2;
                        }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 131 "scan.l"
{
                        } 
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 133 "scan.l"
{ BEGIN oldstate;
                        }    
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 135 "scan.l"
{
                        } 
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 137 "scan.l"
{ crt_line_no++; 
			  BEGIN oldstate;
                        }    
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 140 "scan.l"
{ crt_line_no++; 
                        }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 142 "scan.l"
{ idx = CheckKeyword( yytext );
                          if ( idx < 0 ) { 
                            BEGIN CR_IGNORE;
                            break; 
                          } 
                          BEGIN keywords[idx].next;
                          if ( keywords[idx].cmd ) {
                            crt_section = keywords[idx].cmd;
                            RETURN( keywords[idx].cmd );
                          }
                        } 
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 153 "scan.l"
{ Include( IncName(yytext) );
                          BEGIN CR_IGNORE;
                        } 
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 156 "scan.l"
{ Include( ModelName(yytext) );
                          BEGIN CR_IGNORE;
                        } 
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 159 "scan.l"
{ Include( IntegName(yytext) );
                          BEGIN CR_IGNORE;
                        } 
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 162 "scan.l"
{ strcpy( yylval.str, yytext );
                          BEGIN CR_IGNORE;                         
                          RETURN( PARAMETER ); 
                        }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 166 "scan.l"
{ ScanError("Extra parameter on command line '%s'", yytext);
                        }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 168 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( ATOMID );
                        }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 171 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 173 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( SPCSPC );
                        }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 176 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( SPCNR );
                        }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 179 "scan.l"
{ RETURN( SPCEQUAL );
                        } 
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 181 "scan.l"
{ RETURN( SPCPLUS );
                        } 
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 183 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 185 "scan.l"
{ ScanError("Invalid character '%c' in species definition", yytext[0] );
                        }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 187 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( SSPID );
                        }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 190 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 192 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( INISPC ); 
                        } 
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 195 "scan.l"
{ RETURN( INIEQUAL );
                        } 
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 197 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 199 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( INIVALUE ); 
                        } 
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 202 "scan.l"
{ ScanError("Invalid character '%c' in initial values", yytext[0] );
                        }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 204 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( EQNSPC );
                        } 
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 207 "scan.l"
{ RETURN( EQNEQUAL );
                        } 
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 209 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( EQNCOEF ); 
                        } 
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 212 "scan.l"
{ BEGIN RATE_STATE;
                          *crt_rate = 0;
                          RETURN( EQNCOLON );
                        } 
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 216 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( EQNSIGN );
                        } 
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 219 "scan.l"
{ BEGIN EQNTAG_STATE;
                          RETURN( EQNLESS );
			}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 222 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( EQNTAG );
                        } 
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 225 "scan.l"
{ BEGIN EQN_STATE;
                          RETURN( EQNGREATER );
                        }    
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 228 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( RATE );
                        } 
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 231 "scan.l"
{ BEGIN EQN_STATE;
                          RETURN( yytext[0] );
                        } 
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 234 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( LMPSPC );
                        }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 237 "scan.l"
{ RETURN( LMPPLUS );
                        } 
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 239 "scan.l"
{ RETURN( LMPCOLON );
                        } 
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 241 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 45:
/* rule 45 can match eol */
YY_RULE_SETUP
#line 243 "scan.l"
{ ScanError("Invalid character '%c' in species definition", yytext[0] );
                        }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 245 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( LKTID );
                        }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 248 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 250 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( TPTID );
                        }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 253 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 255 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( USEID );
                        }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 258 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 260 "scan.l"
{ strcpy( yylval.str, yytext );
                          RETURN( MNIID );
                        }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 263 "scan.l"
{ RETURN( yytext[0] );
                        } 
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 265 "scan.l"
{ strcpy( yylval.str, yytext );
                          BEGIN INL_CODE;
			  RETURN( INLCTX );
			}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 269 "scan.l"
{ if ( EqNoCase( yytext+1, "ENDINLINE" ) ){
                            BEGIN INITIAL;
                            RETURN( ENDINLINE );
			  }
			  else {
                            strcpy( yylval.str, yytext );
                            RETURN( INCODE );
			  }
			}
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 278 "scan.l"
{ crt_line_no++;
			  strcpy( yylval.str,yytext );
			  RETURN( INCODE );
			}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 282 "scan.l"
{ strcpy( yylval.str,yytext );
		          RETURN( INCODE );
			}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(CMD_STATE):
case YY_STATE_EOF(INC_STATE):
case YY_STATE_EOF(MOD_STATE):
case YY_STATE_EOF(INT_STATE):
case YY_STATE_EOF(PRM_STATE):
case YY_STATE_EOF(DSP_STATE):
case YY_STATE_EOF(SSP_STATE):
case YY_STATE_EOF(INI_STATE):
case YY_STATE_EOF(EQN_STATE):
case YY_STATE_EOF(EQNTAG_STATE):
case YY_STATE_EOF(RATE_STATE):
case YY_STATE_EOF(LMP_STATE):
case YY_STATE_EOF(CR_IGNORE):
case YY_STATE_EOF(SC_IGNORE):
case YY_STATE_EOF(ATM_STATE):
case YY_STATE_EOF(LKT_STATE):
case YY_STATE_EOF(INL_STATE):
case YY_STATE_EOF(MNI_STATE):
case YY_STATE_EOF(TPT_STATE):
case YY_STATE_EOF(USE_STATE):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(COMMENT2):
case YY_STATE_EOF(EQN_ID):
case YY_STATE_EOF(INL_CODE):
#line 285 "scan.l"
{ if ( ! EndInclude() ) {
                            RETURN( INITIAL );
                          }
                        }  
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 289 "scan.l"
ECHO;
	YY_BREAK
#line 1528 "lex.yy.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 199 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 199 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 198);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 289 "scan.l"



  KEYWORD keywords[] = { { "INCLUDE",    INC_STATE, 0 },
                         { "MODEL",      MOD_STATE, 0 },
                         { "INTEGRATOR", INT_STATE, 0 },
                         { "JACOBIAN",   PRM_STATE, JACOBIAN }, 
                         { "HESSIAN",    PRM_STATE, HESSIAN }, 
                         { "DECLARE",    PRM_STATE, DECLARE }, 
                         { "STOICMAT",   PRM_STATE, STOICMAT }, 
                         { "STOCHASTIC", PRM_STATE, STOCHASTIC }, 
                         { "DOUBLE",     PRM_STATE, DOUBLE }, 
                         { "REORDER",    PRM_STATE, REORDER }, 
                         { "MEX",        PRM_STATE, MEX }, 
                         { "DUMMYINDEX", PRM_STATE, DUMMYINDEX}, 
                         { "EQNTAGS",    PRM_STATE, EQNTAGS}, 
                         { "FUNCTION",   PRM_STATE, FUNCTION }, 
                         { "ATOMS",      ATM_STATE, ATOMDECL },   
                         { "CHECK",      ATM_STATE, CHECK },
                         { "CHECKALL",   INITIAL,   CHECKALL },
                         { "DEFVAR",     DSP_STATE, DEFVAR }, 
                         { "DEFRAD",     DSP_STATE, DEFRAD }, 
                         { "DEFFIX",     DSP_STATE, DEFFIX }, 
                         { "SETVAR",     SSP_STATE, SETVAR }, 
                         { "SETRAD",     SSP_STATE, SETRAD }, 
                         { "SETFIX",     SSP_STATE, SETFIX }, 
                         { "INITVALUES", INI_STATE, INITVALUES }, 
                         { "EQUATIONS",  EQN_STATE, EQUATIONS }, 
                         { "LUMP",       LMP_STATE, LUMP }, 
                         { "LOOKAT", 	 LKT_STATE, LOOKAT },
                         { "LOOKATALL",  INITIAL,   LOOKATALL },
                         { "TRANSPORT",  TPT_STATE, TRANSPORT },
                         { "TRANSPORTALL", INITIAL,   TRANSPORTALL },
                         { "INITIALIZE", PRM_STATE, INITIALIZE },
                         { "XGRID",  	 PRM_STATE, XGRID },
                         { "YGRID",  	 PRM_STATE, YGRID },
                         { "ZGRID",  	 PRM_STATE, ZGRID },
                         { "MONITOR", 	 MNI_STATE, MONITOR },
                         { "WRITE_ATM",  INITIAL,   WRITE_ATM },
                         { "WRITE_SPC",  INITIAL,   WRITE_SPC },
                         { "WRITE_MAT",  INITIAL,   WRITE_MAT },
                         { "WRITE_OPT",  INITIAL,   WRITE_OPT },
                         { "USE",        PRM_STATE, USE },
                         { "LANGUAGE",   PRM_STATE, LANGUAGE },
                         { "INLINE",     INL_STATE, INLINE },
                         { "ENDINLINE",  INITIAL,   ENDINLINE },
                         { "INTFILE",    PRM_STATE, INTFILE },
                         { "DRIVER",     PRM_STATE, DRIVER },
                         { "RUN",        PRM_STATE, RUN },
                         { "USES",       USE_STATE, USES },
                         { "SPARSEDATA", PRM_STATE, SPARSEDATA },
                         { 0, 0, 0 } 
                       };

void Include ( char * name )
{
FILE *f;
YY_BUFFER_STATE newb;

  if ( yy_buf_level == MAX_INCLUDE ) {
    printf("\nInclude nested too deep. Include %s ignored", name);
    return;
  }

  yy_buffers[ yy_buf_level ]  = YY_CURRENT_BUFFER;
  yy_line_no[ yy_buf_level ]  = crt_line_no;
  yy_filename[ yy_buf_level ] = crt_filename;
  yy_buf_level++;
  
  crt_line_no = 1;  

  crt_filename = malloc( 1 + strlen( name ) );
  strcpy( crt_filename, name ); 

 
  f = fopen( name, "r" );
  if( f == 0 )
    FatalError(3,"%s: Can't read file", name );

  newb = yy_create_buffer(f,YY_BUF_SIZE);
  yy_switch_to_buffer(newb );
}

int EndInclude()
{
YY_BUFFER_STATE oldb;
char * oldn;

  if ( yy_buf_level > 0 ) {
    oldb = YY_CURRENT_BUFFER;
    oldn = crt_filename; 
    yy_buf_level--;
    yy_switch_to_buffer(yy_buffers[yy_buf_level] );
    crt_line_no = yy_line_no[ yy_buf_level ];
    crt_filename = yy_filename[ yy_buf_level ]; 
    yy_delete_buffer(oldb ); 
    free( oldn );
    return 1;
  } 
  return 0;
}

int EqNoCase( char *s1, char *s2 )
{
  while( *s1 ) {
    if ( toupper(*s1++) != toupper(*s2++) ) return 0;
  }
  return *s1 == *s2;
}

int CheckKeyword( char *cmd )
{
int i;

  i = 0;
  while( 1 ) {
    if( keywords[i].name == 0 ) {
      ScanError( "'%s': Unknown command (ignored)", cmd);
      return -1;
    }
    if( EqNoCase( cmd, keywords[i].name ) ) {
      return i;
    }
    i++;
  }
}


